@@ -1,25 +1,27 @@
 import { Provider } from './provider';
 import { applyAction, clickByText, inputText } from '../../utils/utils';
-import { addButton, removeButton } from '../types/constants';
+import { addButton, removeButton, trTag, SEC } from '../types/constants';
 import { OcpVirtData } from '../types/types';
 import {
   ocpinstanceName,
   instanceUrl,
   instanceToken,
-  addButtonModal,
+  // addButtonModal,
   ocpVMenu,
+  dataLabel,
+  addButtonModal,
 } from '../views/providerOcpV.view';
 
 export class ProviderocpV extends Provider {
-  protected fillocpname(name: string) {
+  protected fillocpname(name: string): void {
     inputText(ocpinstanceName, name);
   }
 
-  protected fillinstanceUrl(url: string) {
+  protected fillinstanceUrl(url: string): void {
     inputText(instanceUrl, url);
   }
 
-  protected filltoken(token: string) {
+  protected filltoken(token: string): void {
     inputText(instanceToken, token);
   }
 
@@ -32,7 +34,22 @@ export class ProviderocpV extends Provider {
     clickByText(addButtonModal, addButton);
   }
 
-  delete(providerData: OcpVirtData) {
+  protected populate(providerData: OcpVirtData): void {
+    Provider.openList();
+    const { name } = providerData;
+    cy.contains(name)
+      .parent(trTag)
+      .within(() => {
+        // Validating that provider is in `Ready` state
+        cy.get(dataLabel.status, { timeout: 600 * SEC }).should('have.text', 'Ready');
+        // Verifying that network field is not empty and count is not 0
+        cy.get(dataLabel.networks).invoke('text').then(parseFloat).should('be.gt', 0);
+        // Verifying that datastore field is not empty and count is not 0
+        cy.get(dataLabel.datastores).invoke('text').then(parseFloat).should('be.gt', 0);
+      });
+  }
+
+  delete(providerData: OcpVirtData): void {
     const { name, type } = providerData;
     Provider.openList();
     clickByText(ocpVMenu, type);
@@ -42,5 +59,6 @@ export class ProviderocpV extends Provider {
   create(providerData: OcpVirtData): void {
     this.openMenu();
     this.runWizard(providerData);
+    this.populate(providerData);
   }
 }
