@@ -40,7 +40,7 @@ export type PlanData = {
   sProvider: string;
   tProvider: string;
   namespace: string;
-  vmwareSourceFqdn: string;
+  sourceClusterName: string;
   vmwareSourceVmList: string[];
   useExistingNetworkMapping: boolean;
   useExistingStorageMapping: boolean;
@@ -48,6 +48,7 @@ export type PlanData = {
   targetProvider?: ProviderData;
   networkMappingData: MappingData;
   storageMappingData: MappingData;
+  warmMigration?: boolean;
 };
 export type TestData = {
   loginData: LoginData;
