@@ -1,8 +1,8 @@
-export const instanceName = '#vmware-name';
-export const instanceHostname = '#vmware-hostname';
-export const instanceUsername = '#vmware-username';
-export const instancePassword = '#vmware-password';
-export const instanceFingerprint = '#vmware-fingerprint';
+export const instanceName = '#name';
+export const instanceHostname = '#hostname';
+export const instanceUsername = '#username';
+export const instancePassword = '#password';
+export const instanceFingerprint = '#fingerprint';
 export const addButtonModal =
   '#pf-modal-part-0 > footer > div > div > button.pf-c-button.pf-m-primary';
 export const vmwareMenu = '.pf-c-tabs__link';
