@@ -1,9 +1,9 @@
 import * as React from 'react';
 import { Button, ButtonProps } from '@patternfly/react-core';
-import spacing from '@patternfly/react-styles/css/utilities/Spacing/spacing';
 import ConditionalTooltip from '@app/common/components/ConditionalTooltip';
 import { useHasSufficientProvidersQuery } from '@app/queries';
 import { useHistory } from 'react-router-dom';
+import { PROVIDER_TYPE_NAMES } from '@app/common/constants';
 
 interface ICreatePlanButtonProps {
   variant?: ButtonProps['variant'];
@@ -18,18 +18,17 @@ const CreatePlanButton: React.FunctionComponent<ICreatePlanButtonProps> = ({
   return (
     <ConditionalTooltip
       isTooltipEnabled={!hasSufficientProviders}
-      content="You must add at least one VMware provider and one OpenShift Virtualization provider in order to create a migration plan."
+      content={`You must add at least one ${PROVIDER_TYPE_NAMES.vsphere} or ${PROVIDER_TYPE_NAMES.ovirt} provider and one ${PROVIDER_TYPE_NAMES.openshift} provider in order to create a migration plan.`}
     >
-      <div className={`${spacing.mtMd}`}>
-        <Button
-          onClick={() => history.push('/plans/create')}
-          isDisabled={!hasSufficientProviders}
-          variant={variant}
-          id="create-plan-button"
-        >
-          Create plan
-        </Button>
-      </div>
+      <Button
+        isSmall
+        onClick={() => history.push('/plans/create')}
+        isAriaDisabled={!hasSufficientProviders}
+        variant={variant}
+        id="create-plan-button"
+      >
+        Create plan
+      </Button>
     </ConditionalTooltip>
   );
 };
