@@ -1,10 +1,10 @@
+import { UnknownResult } from '@app/common/types';
 import * as React from 'react';
-import { QueryResult, MutationResult } from 'react-query';
 import { ResolvedQueries, IResolvedQueriesProps } from './ResolvedQueries';
 
 export interface IResolvedQueryProps
   extends Omit<IResolvedQueriesProps, 'results' | 'errorTitles'> {
-  result: QueryResult<unknown> | MutationResult<unknown>;
+  result: UnknownResult;
   errorTitle: string;
 }
 
