@@ -4,6 +4,7 @@ import { CLUSTER_API_VERSION, META } from '@app/common/constants';
 import { nameAndNamespace } from '../helpers';
 import { MOCK_NETWORK_MAPPINGS, MOCK_STORAGE_MAPPINGS } from './mappings.mock';
 import { MOCK_OPENSHIFT_NAMESPACES } from './namespaces.mock';
+import { MOCK_HOOKS } from './hooks.mock';
 
 export let MOCK_PLANS: IPlan[];
 
@@ -174,8 +175,6 @@ if (process.env.NODE_ENV === 'test' || process.env.DATA_SOURCE === 'mock') {
     metadata: {
       name: 'plantest-01',
       namespace: 'openshift-migration',
-      generation: 2,
-      resourceVersion: '30825024',
       selfLink:
         '/apis/forklift.konveyor.io/v1beta1/namespaces/openshift-migration/plans/plantest-01',
       uid: '28fde094-b667-4d21-8f29-27c18f22178c',
@@ -231,7 +230,6 @@ if (process.env.NODE_ENV === 'test' || process.env.DATA_SOURCE === 'mock') {
           type: 'Ready',
         },
       ],
-      observedGeneration: 2,
       migration: {
         active: '',
         started: '2020-10-10T14:04:10Z',
@@ -260,8 +258,6 @@ if (process.env.NODE_ENV === 'test' || process.env.DATA_SOURCE === 'mock') {
     metadata: {
       name: 'plantest-02',
       namespace: 'openshift-migration',
-      generation: 2,
-      resourceVersion: '30825024',
       selfLink:
         '/apis/forklift.konveyor.io/v1beta1/namespaces/openshift-migration/plans/plantest-02',
       uid: '28fde094-b667-4d21-8f29-27c18f22178c',
@@ -282,7 +278,21 @@ if (process.env.NODE_ENV === 'test' || process.env.DATA_SOURCE === 'mock') {
         network: nameAndNamespace(MOCK_NETWORK_MAPPINGS[0].metadata),
         storage: nameAndNamespace(MOCK_STORAGE_MAPPINGS[0].metadata),
       },
-      vms: [vm1],
+      vms: [
+        {
+          ...vm1,
+          hooks: [
+            {
+              hook: nameAndNamespace(MOCK_HOOKS[0].metadata),
+              step: 'PreHook',
+            },
+            {
+              hook: nameAndNamespace(MOCK_HOOKS[1].metadata),
+              step: 'PostHook',
+            },
+          ],
+        },
+      ],
       warm: false,
     },
     status: {
@@ -296,7 +306,6 @@ if (process.env.NODE_ENV === 'test' || process.env.DATA_SOURCE === 'mock') {
           type: 'Ready',
         },
       ],
-      observedGeneration: 2,
     },
   };
 
@@ -323,8 +332,6 @@ if (process.env.NODE_ENV === 'test' || process.env.DATA_SOURCE === 'mock') {
     metadata: {
       name: 'plantest-03',
       namespace: 'openshift-migration',
-      generation: 2,
-      resourceVersion: '30825023',
       selfLink:
         '/apis/forklift.konveyor.io/v1beta1/namespaces/openshift-migration/plans/plantest-03',
       uid: '28fde094-b667-4d21-8f29-27c18f22178c',
@@ -364,7 +371,6 @@ if (process.env.NODE_ENV === 'test' || process.env.DATA_SOURCE === 'mock') {
           type: 'Ready',
         },
       ],
-      observedGeneration: 2,
       migration: {
         active: '',
         started: '2020-10-10T14:04:10Z',
@@ -393,8 +399,6 @@ if (process.env.NODE_ENV === 'test' || process.env.DATA_SOURCE === 'mock') {
     metadata: {
       name: 'plantest-04',
       namespace: 'openshift-migration',
-      generation: 2,
-      resourceVersion: '30825024',
       selfLink:
         '/apis/forklift.konveyor.io/v1beta1/namespaces/openshift-migration/plans/plantest-04',
       uid: '28fde094-b667-4d21-8f29-27c18f22178c',
@@ -434,7 +438,6 @@ if (process.env.NODE_ENV === 'test' || process.env.DATA_SOURCE === 'mock') {
           type: 'Ready',
         },
       ],
-      observedGeneration: 2,
       migration: {
         active: '',
         started: '2020-10-10T14:04:10Z',
@@ -465,14 +468,14 @@ if (process.env.NODE_ENV === 'test' || process.env.DATA_SOURCE === 'mock') {
         ...vmStatus1.pipeline[0],
         error: {
           phase: 'DiskTransferFailed',
-          reasons: ['Error transferring disks'],
+          reasons: ['Could not transfer disks'],
         },
       },
       { ...vmStatus1.pipeline[1], started: undefined },
     ],
     error: {
       phase: 'DiskTransfer',
-      reasons: ['Error transferring disks'],
+      reasons: ['Could not transfer disks'],
     },
   };
 
@@ -485,13 +488,13 @@ if (process.env.NODE_ENV === 'test' || process.env.DATA_SOURCE === 'mock') {
         completed: '2020-10-10T15:58:10Z',
         error: {
           phase: 'ImageConversionFailed',
-          reasons: ['Error converting image'],
+          reasons: ['Could not convert image'],
         },
       },
     ],
     error: {
       phase: 'ImageConversion',
-      reasons: ['Error converting image'],
+      reasons: ['Could not convert image'],
     },
   };
 
@@ -518,7 +521,6 @@ if (process.env.NODE_ENV === 'test' || process.env.DATA_SOURCE === 'mock') {
           type: 'Ready',
         },
       ],
-      observedGeneration: 2,
       migration: {
         active: '',
         started: '2020-10-10T14:04:10Z',
@@ -547,8 +549,6 @@ if (process.env.NODE_ENV === 'test' || process.env.DATA_SOURCE === 'mock') {
     metadata: {
       name: 'plantest-06',
       namespace: 'openshift-migration',
-      generation: 2,
-      resourceVersion: '30825024',
       selfLink:
         '/apis/forklift.konveyor.io/v1beta1/namespaces/openshift-migration/plans/plantest-06',
       uid: '28fde094-b667-4d21-8f29-27c18f22178c',
@@ -580,7 +580,6 @@ if (process.env.NODE_ENV === 'test' || process.env.DATA_SOURCE === 'mock') {
           type: 'Ready',
         },
       ],
-      observedGeneration: 2,
     },
   };
 
@@ -731,7 +730,6 @@ if (process.env.NODE_ENV === 'test' || process.env.DATA_SOURCE === 'mock') {
           type: 'Ready',
         },
       ],
-      observedGeneration: 2,
       migration: {
         active: '',
         started: '2020-10-10T14:04:10Z',
@@ -760,7 +758,6 @@ if (process.env.NODE_ENV === 'test' || process.env.DATA_SOURCE === 'mock') {
     spec: { ...plan7.spec, description: 'cutover started', vms: [vm1, vm2, vm3] },
     status: {
       conditions: plan7.status?.conditions || [],
-      observedGeneration: 2,
       migration: {
         active: '',
         started: '2020-10-10T14:04:10Z',
@@ -806,7 +803,6 @@ if (process.env.NODE_ENV === 'test' || process.env.DATA_SOURCE === 'mock') {
           type: 'Ready',
         },
       ],
-      observedGeneration: 2,
       migration: {
         active: '',
         started: '2020-10-10T14:04:10Z',
@@ -845,7 +841,6 @@ if (process.env.NODE_ENV === 'test' || process.env.DATA_SOURCE === 'mock') {
           type: 'Ready',
         },
       ],
-      observedGeneration: 2,
       migration: {
         active: '',
         started: '2020-10-10T14:04:10Z',
