@@ -1,4 +1,3 @@
-import { QueryResult } from 'react-query';
 import { ForkliftResource, ForkliftResourceKind } from '@app/client/helpers';
 import { IKubeList } from '@app/client/types';
 import { META } from '@app/common/constants';
@@ -10,15 +9,13 @@ import { MOCK_PROVISIONERS } from './mocks/provisioners.mock';
 
 const provisionerResource = new ForkliftResource(ForkliftResourceKind.Provisioners, META.namespace);
 
-export const useProvisionersQuery = (): QueryResult<IKubeList<IProvisioner>> => {
+export const useProvisionersQuery = () => {
   const client = useAuthorizedK8sClient();
   return useMockableQuery<IKubeList<IProvisioner>>(
     {
       queryKey: 'provisioners',
       queryFn: async () => (await client.list<IKubeList<IProvisioner>>(provisionerResource)).data,
-      config: {
-        refetchInterval: usePollingContext().refetchInterval,
-      },
+      refetchInterval: usePollingContext().refetchInterval,
     },
     mockKubeList(MOCK_PROVISIONERS, 'Provisioner')
   );
