@@ -138,7 +138,14 @@ class ContextModule extends Module {
 		const m = /** @type {ContextModule} */ (module);
 		this.resolveDependencies = m.resolveDependencies;
 		this.options = m.options;
-		this.resolveOptions = m.resolveOptions;
+	}
+
+	/**
+	 * Assuming this module is in the cache. Remove internal references to allow freeing some memory.
+	 */
+	cleanupForCache() {
+		super.cleanupForCache();
+		this.resolveDependencies = undefined;
 	}
 
 	prettyRegExp(regexString) {
@@ -1009,9 +1016,9 @@ module.exports = webpackEmptyAsyncContext;`;
 			this.getSource(this.getSourceString(this.options.mode, context))
 		);
 		const set = new Set();
-		const allDeps = /** @type {ContextElementDependency[]} */ (this.dependencies.concat(
-			this.blocks.map(b => b.dependencies[0])
-		));
+		const allDeps = /** @type {ContextElementDependency[]} */ (
+			this.dependencies.concat(this.blocks.map(b => b.dependencies[0]))
+		);
 		set.add(RuntimeGlobals.module);
 		set.add(RuntimeGlobals.hasOwnProperty);
 		if (allDeps.length > 0) {
