@@ -17,3 +17,5 @@ export * from './TableText';
 export * from './utils';
 export * from './TableTypes';
 export * from './TableContext';
+export * from './FavoritesCell';
+export * from './TreeRowWrapper';
